import{L as o}from"./main-01106cc7.js";const a=()=>import("./c.c3426c84.js"),c=(c,i,l)=>new Promise(n=>{const m=i.cancel,r=i.confirm;o(c,"show-dialog",{dialogTag:"dialog-box",dialogImport:a,dialogParams:{...i,...l,cancel:()=>{n(!(null==l||!l.prompt)&&null),m&&m()},confirm:o=>{n(null==l||!l.prompt||o),r&&r(o)}}})}),i=(o,a)=>c(o,a),l=(o,a)=>c(o,a,{confirmation:!0});export{i as a,l as s};
